/* See https://developer.gnome.org/pygtk/stable/pango-markup-language.html */
b        { font-weight: bold }
big      { font-size: larger }
i        { font-style: italic }
small    { font-size: smaller }
s        { text-decoration: line-through }
sub, sup { font-size: .83em }
sub      { vertical-align: sub }
sup      { vertical-align: super }
tt       { font-family: monospace }
u        { text-decoration: underline }
